@@ -10,9 +10,9 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MARIADB_CLIENT_VERSION_STR	"10.11.11"
+#define MARIADB_CLIENT_VERSION_STR	"10.11.13"
 #define MARIADB_BASE_VERSION		"mariadb-10.11"
-#define MARIADB_VERSION_ID		101111
+#define MARIADB_VERSION_ID		101113
 #define MARIADB_PORT	        	3306
 #define MARIADB_UNIX_ADDR               "/tmp/mysql.sock"
 #ifndef MYSQL_UNIX_ADDR
@@ -23,13 +23,13 @@
 #endif
 
 #define MYSQL_CONFIG_NAME               "my"
-#define MYSQL_VERSION_ID                101111
-#define MYSQL_SERVER_VERSION            "10.11.11-MariaDB"
+#define MYSQL_VERSION_ID                101113
+#define MYSQL_SERVER_VERSION            "10.11.13-MariaDB"
 
-#define MARIADB_PACKAGE_VERSION "3.3.14"
-#define MARIADB_PACKAGE_VERSION_ID 30314
+#define MARIADB_PACKAGE_VERSION "3.3.16"
+#define MARIADB_PACKAGE_VERSION_ID 30316
 #define MARIADB_SYSTEM_TYPE "NetBSD"
-#define MARIADB_MACHINE_TYPE "earmv7hf"
+#define MARIADB_MACHINE_TYPE "aarch64eb"
 #define MARIADB_PLUGINDIR "/usr/pkg/lib/mysql/plugin"
 
 /* mysqld compile time options */
